@@ -15,13 +15,18 @@ void setup_speech() {
 
   Bonobo_ServerInfoList *servers;
   Bonobo_ServerInfo *info;
-  CORBA_Object rv;
+  CORBA_Object rv=NULL;
 
-  servers = bonobo_activation_query (
-	     "repo_ids.has ('IDL:GNOME/Speech/SynthesisDriver:0.3')",
-	     NULL, &ev);
+  servers = bonobo_activation_query ("repo_ids.has_one(['IDL:GNOME/Speech/SynthesisDriver:0.2','IDL:GNOME/Speech/SynthesisDriver:0.3'])", NULL, &ev);
 
-  for (int i=0; i<servers->_length; i++) 
+  if (servers->_length==0) {
+    speaker=NULL;
+    printf(_("Unable to initialize speech support\n"));
+    fflush(stdout);
+    return;
+  }
+
+  for (unsigned int i=0; i<servers->_length; i++) 
     {
       CORBA_exception_init (&ev);
 
@@ -41,7 +46,7 @@ void setup_speech() {
 
   voices = GNOME_Speech_SynthesisDriver_getAllVoices (rv, &ev);
 
-  if (voices==NULL || BONOBO_EX (&ev)) {
+  if (voices==NULL || BONOBO_EX (&ev) || voices->_length==0) {
     printf(_("Unable to initialize voices"));
     speaker=NULL;
     return;
@@ -52,7 +57,6 @@ void setup_speech() {
                                                         &ev);
 
   GNOME_Speech_ParameterList *list;
-  int i;
   list = GNOME_Speech_Speaker_getSupportedParameters (speaker, &ev);
   if (BONOBO_EX (&ev) || list->_length == 0)
     {
@@ -61,7 +65,7 @@ void setup_speech() {
       printf(_("Warning: unable to set speech parameters\n"));
       return;
     }
-  for (i = 0; i < list->_length; i++)
+  for (unsigned i = 0; i < list->_length; i++)
     {
       GNOME_Speech_Parameter *p = &(list->_buffer[i]);
       if (!strcmp (p->name, "rate")) {
