@@ -65,6 +65,8 @@ gboolean textentry=FALSE;
 gboolean stdoutpipe=FALSE;
 extern gboolean setup,paused;
 extern int optind;
+extern ControlTree *controltree;
+extern const gchar* filename;
 
 GdkFilterReturn dasher_discard_take_focus_filter (GdkXEvent *xevent, GdkEvent *event, gpointer data)
 {
@@ -204,7 +206,6 @@ main(int argc, char *argv[])
   paused=true;
 
   glade_xml_signal_autoconnect(xml);
-  open_window(xml);
 
   if (preferences==TRUE) {
     window = glade_xml_get_widget(xml, "preferences");
@@ -212,6 +213,8 @@ main(int argc, char *argv[])
     window = glade_xml_get_widget(xml, "window");
   }
 
+  open_window(xml);
+
   dasher_late_initialise(360,360);
 
   interface_late_setup();
@@ -241,8 +244,6 @@ main(int argc, char *argv[])
   XSetWMProtocols (GDK_WINDOW_XDISPLAY (window->window),GDK_WINDOW_XWINDOW (window->window), wm_window_protocols, 3);
   gdk_window_add_filter (window->window, dasher_discard_take_focus_filter, NULL);
   
-  choose_filename();
-
   dasher_pause(0,0); // we start paused
 
 #ifdef GNOME_SPEECH
@@ -253,10 +254,22 @@ main(int argc, char *argv[])
   setupa11y();
 #endif
 
-  add_control_tree(gettree());
+  controltree=gettree();
+  add_control_tree(controltree);
 
   if (optind<argc) {
-    open_file(argv[optind]);
+    if (!g_path_is_absolute(argv[optind])) {
+      char *cwd;
+      cwd=(char *)malloc(1024*sizeof(char));
+      getcwd(cwd,1024);
+      filename=g_build_path("/",cwd,argv[optind],NULL);
+      open_file(filename);
+    } else {
+      filename=argv[optind];
+      open_file(filename);
+    }
+  } else {
+    choose_filename();
   }
 
   gtk_main ();
